pub struct StartStep {
pub role_id: Option<RoleId>,
pub step_id: StepId,
pub lease: StepLease,
pub now: OffsetDateTime,
pub max_parallel_ceiling: MaxParallel,
pub budget_reservation_id: Option<BudgetReservationId>,
}Expand description
Take a step to run under a lease.
role_id names the seat taking it and is checked against the
definition; absent, the engine takes the step and the event names
the seat the definition assigns to it.
Fields
role_id: Option<RoleId>step_id: StepIdlease: StepLeasenow: OffsetDateTimemax_parallel_ceiling: MaxParallelbudget_reservation_id: Option<BudgetReservationId>Trait Implementations
impl Eq for StartStep
impl StructuralPartialEq for StartStep