pub struct HostDeliveryQuery { /* private fields */ }Expand description
One page of a question about what the ledger holds.
Implementations
Sourceimpl HostDeliveryQuery
impl HostDeliveryQuery
pub fn new() -> Self
pub fn in_ceremony(self, ceremony_id: CeremonyId) -> Self
pub fn in_state(self, state: HostDeliveryStateKind) -> Self
pub fn to(self, target: HostDeliveryTargetFilter) -> Self
pub const fn of_size(self, limit: HostDeliveryPageLimit) -> Self
Sourcepub fn after(self, cursor: HostDeliveryId) -> Self
pub fn after(self, cursor: HostDeliveryId) -> Self
Continue after the last identifier of the previous page.
pub const fn ceremony_id(&self) -> Option<&CeremonyId>
pub const fn state(&self) -> Option<HostDeliveryStateKind>
pub const fn target(&self) -> &HostDeliveryTargetFilter
pub const fn limit(&self) -> HostDeliveryPageLimit
pub const fn cursor(&self) -> Option<&HostDeliveryId>
Sourcepub fn admits(&self, record: &HostDeliveryRecord) -> bool
pub fn admits(&self, record: &HostDeliveryRecord) -> bool
Whether a record belongs on this page, cursor aside.