AuthorizationScopeResolverPort

Trait AuthorizationScopeResolverPort 

pub trait AuthorizationScopeResolverPort: Send + Sync {
    // Required methods
    fn ceremony_scope<'life0, 'life1, 'async_trait>(
        &'life0 self,
        ceremony_id: &'life1 CeremonyId,
    ) -> Pin<Box<dyn Future<Output = Result<AuthorizationScope, DomainError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn child_parent_scope<'life0, 'life1, 'async_trait>(
        &'life0 self,
        child_id: &'life1 CeremonyId,
    ) -> Pin<Box<dyn Future<Output = Result<AuthorizationScope, DomainError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn budget_scope<'life0, 'life1, 'async_trait>(
        &'life0 self,
        ceremony_id: &'life1 CeremonyId,
    ) -> Pin<Box<dyn Future<Output = Result<AuthorizationScope, DomainError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Resolves authorization scopes from authoritative runtime state before a protected facade operation reads or mutates that state.

Required Methods

fn ceremony_scope<'life0, 'life1, 'async_trait>( &'life0 self, ceremony_id: &'life1 CeremonyId, ) -> Pin<Box<dyn Future<Output = Result<AuthorizationScope, DomainError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn child_parent_scope<'life0, 'life1, 'async_trait>( &'life0 self, child_id: &'life1 CeremonyId, ) -> Pin<Box<dyn Future<Output = Result<AuthorizationScope, DomainError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn budget_scope<'life0, 'life1, 'async_trait>( &'life0 self, ceremony_id: &'life1 CeremonyId, ) -> Pin<Box<dyn Future<Output = Result<AuthorizationScope, DomainError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors