CeremonyTranscriptStorePort

Trait CeremonyTranscriptStorePort 

pub trait CeremonyTranscriptStorePort: Send + Sync {
    // Required methods
    fn append<'life0, 'life1, 'async_trait>(
        &'life0 self,
        instance_id: &'life1 CeremonyId,
        contribution: CeremonyStepContribution,
    ) -> Pin<Box<dyn Future<Output = Result<(), DomainError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn transcript<'life0, 'life1, 'async_trait>(
        &'life0 self,
        instance_id: &'life1 CeremonyId,
    ) -> Pin<Box<dyn Future<Output = Result<CeremonyTranscript, DomainError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Stores and retrieves the transcript a ceremony accumulates as its steps execute.

Required Methods

fn append<'life0, 'life1, 'async_trait>( &'life0 self, instance_id: &'life1 CeremonyId, contribution: CeremonyStepContribution, ) -> Pin<Box<dyn Future<Output = Result<(), DomainError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Append a step’s contribution to the transcript of instance_id.

fn transcript<'life0, 'life1, 'async_trait>( &'life0 self, instance_id: &'life1 CeremonyId, ) -> Pin<Box<dyn Future<Output = Result<CeremonyTranscript, DomainError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

The transcript accumulated for instance_id so far; an empty transcript when the ceremony has produced nothing yet.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors