DomainEvent

Trait DomainEvent 

pub trait DomainEvent:
    Serialize
    + DeserializeOwned
    + Send
    + Sync
    + 'static { }
Marker trait shared by every published domain event so they can be serialized by the adapter. The marker is automatically implemented for all Serialize + DeserializeOwned + Send + Sync types — no explicit impl DomainEvent for … is required.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors