pub enum HostDeliveryItem {
Intervention {
ceremony_id: CeremonyId,
intervention_id: CeremonyInterventionId,
},
Attention {
ceremony_id: CeremonyId,
attention_id: AttentionEventId,
},
}Expand description
What is being delivered to a host destination.
Variants
Intervention
A supervisor’s open question, addressed to whoever is working.
Attention
A projected reason the integrator should look at the ceremony.
Implementations
Sourceimpl HostDeliveryItem
impl HostDeliveryItem
pub const fn intervention( ceremony_id: CeremonyId, intervention_id: CeremonyInterventionId, ) -> Self
pub const fn attention( ceremony_id: CeremonyId, attention_id: AttentionEventId, ) -> Self
pub const fn ceremony_id(&self) -> &CeremonyId
pub const fn kind(&self) -> HostDeliveryItemKind
Sourcepub fn delivery_id(
&self,
target: &HostDeliveryTarget,
) -> Result<HostDeliveryId, DomainError>
pub fn delivery_id( &self, target: &HostDeliveryTarget, ) -> Result<HostDeliveryId, DomainError>
The deduplicating identity of delivering this item to target.