pub enum HostDeliveryItemKind {
Intervention,
Attention,
}Expand description
Which kind of thing is being delivered to a host destination.
Variants
Intervention
A supervisor’s question or instruction for a working agent.
Attention
A projected reason for an integrator to look at a ceremony.
Implementations