pub struct AgenticSystemDigest(/* private fields */);Expand description
SHA-256 identity of one revision of an agentic system design.
Implementations
Sourceimpl AgenticSystemDigest
impl AgenticSystemDigest
pub const fn from_bytes(bytes: [u8; 32]) -> Self
pub fn parse_hex(value: &str) -> Result<Self, DomainError>
Sourcepub fn of_canonical_form(canonical: &[u8]) -> Self
pub fn of_canonical_form(canonical: &[u8]) -> Self
Seal a canonical encoding of the design into a digest.
pub const fn as_bytes(&self) -> &[u8; 32]
pub fn to_hex(self) -> String