pub struct CeremonyInterventionResponse { /* private fields */ }Implementations
Sourceimpl CeremonyInterventionResponse
impl CeremonyInterventionResponse
pub fn new( role_id: RoleId, content: CeremonyInterventionContent, responded_at: OffsetDateTime, ) -> Self
Sourcepub fn answering_delivery(
self,
executor: DeliveryRecipient,
delivery_id: HostDeliveryId,
) -> Self
pub fn answering_delivery( self, executor: DeliveryRecipient, delivery_id: HostDeliveryId, ) -> Self
The same answer, attributed to the agent that was handed the item.
pub fn from_evidence( role_id: RoleId, evidence_pack: CeremonyEvidencePack, responded_at: OffsetDateTime, ) -> Result<Self, DomainError>
pub fn role_id(&self) -> &RoleId
pub fn content(&self) -> &CeremonyInterventionContent
pub fn evidence_pack(&self) -> Option<&CeremonyEvidencePack>
pub fn responded_at(&self) -> OffsetDateTime
Sourcepub const fn executor(&self) -> Option<&DeliveryRecipient>
pub const fn executor(&self) -> Option<&DeliveryRecipient>
The live agent that gave this answer, when one was named.
Sourcepub const fn delivery_id(&self) -> Option<&HostDeliveryId>
pub const fn delivery_id(&self) -> Option<&HostDeliveryId>
The offer of the item this answer closes, when one was named.