pub struct CeremonyTranscript(/* private fields */);Expand description
The ordered list of contributions accumulated during a ceremony.
Implementations
Sourceimpl CeremonyTranscript
impl CeremonyTranscript
Sourcepub fn new(contributions: Vec<CeremonyStepContribution>) -> Self
pub fn new(contributions: Vec<CeremonyStepContribution>) -> Self
Build a transcript from an ordered list of contributions.
Sourcepub fn appended(self, contribution: CeremonyStepContribution) -> Self
pub fn appended(self, contribution: CeremonyStepContribution) -> Self
Return this transcript extended with contribution appended last.
Sourcepub fn contributions(&self) -> &[CeremonyStepContribution]
pub fn contributions(&self) -> &[CeremonyStepContribution]
The contributions in the order they were produced.