pub struct SystemCeremonyId(/* private fields */);Expand description
The name one composition goes by inside its system.
Distinct from the pinned ceremony name, because a system may compose the same definition twice for two different purposes.
Implementations