pub struct CeremonyAgentStatus { /* private fields */ }Expand description
Bounded host-owned status evidence for one logical worker execution.
Implementations
Sourceimpl CeremonyAgentStatus
impl CeremonyAgentStatus
pub fn new( ceremony_id: CeremonyId, agent_execution_id: CeremonyAgentExecutionId, operation_id: ExecutionOperationId, claim_owner_id: LeaseOwnerId, logical_worker_id: LogicalWorkerId, host_agent_id: LeaseOwnerId, host_agent_incarnation: HostAgentIncarnation, previous_host_agent_id: Option<LeaseOwnerId>, previous_host_agent_incarnation: Option<HostAgentIncarnation>, role_id: RoleId, step_id: StepId, attempt: u32, execution_status: AgentExecutionStatus, liveness: AgentLiveness, source: AgentStatusSource, requested_model: Option<String>, requested_reasoning_effort: Option<String>, actual_model: Option<String>, actual_reasoning_effort: Option<String>, activity: impl Into<String>, blocker: Option<String>, dependency: Option<String>, task_summary: impl Into<String>, evidence_references: Vec<String>, usage_kind: Option<AgentUsageKind>, usage_value: Option<u64>, observed_at: OffsetDateTime, report_sequence: u64, idempotency_key: impl Into<String>, claim_fence: StepClaimFence, ) -> Result<Self, DomainError>
pub fn ceremony_id(&self) -> &CeremonyId
pub fn agent_execution_id(&self) -> &CeremonyAgentExecutionId
pub const fn operation_id(&self) -> &ExecutionOperationId
pub const fn claim_owner_id(&self) -> &LeaseOwnerId
pub fn logical_worker_id(&self) -> &LogicalWorkerId
pub fn host_agent_id(&self) -> &LeaseOwnerId
pub fn host_agent_incarnation(&self) -> &HostAgentIncarnation
pub fn previous_host_agent_id(&self) -> Option<&LeaseOwnerId>
pub fn previous_host_agent_incarnation(&self) -> Option<&HostAgentIncarnation>
pub fn role_id(&self) -> &RoleId
pub fn step_id(&self) -> &StepId
pub fn attempt(&self) -> u32
pub fn execution_status(&self) -> AgentExecutionStatus
pub fn liveness(&self) -> AgentLiveness
pub fn source(&self) -> AgentStatusSource
pub fn requested_model(&self) -> Option<&str>
pub fn requested_reasoning_effort(&self) -> Option<&str>
pub fn actual_model(&self) -> Option<&str>
pub fn actual_reasoning_effort(&self) -> Option<&str>
pub fn activity(&self) -> &str
pub fn blocker(&self) -> Option<&str>
pub fn dependency(&self) -> Option<&str>
pub fn task_summary(&self) -> &str
pub fn evidence_references(&self) -> &[String]
pub const fn usage_kind(&self) -> Option<AgentUsageKind>
pub fn usage_value(&self) -> Option<u64>
pub fn observed_at(&self) -> OffsetDateTime
pub fn report_sequence(&self) -> u64
pub fn idempotency_key(&self) -> &str
pub const fn claim_fence(&self) -> &StepClaimFence
Sourcepub fn projected_at(&self, now: OffsetDateTime, stale_after: Duration) -> Self
pub fn projected_at(&self, now: OffsetDateTime, stale_after: Duration) -> Self
Project liveness from the age of explicit host evidence without changing the execution outcome or the persisted observation.
Sourcepub fn has_same_logical_execution_as(&self, other: &Self) -> bool
pub fn has_same_logical_execution_as(&self, other: &Self) -> bool
Identity that belongs to the ceremony’s logical participant and its accepted work, rather than to the host process currently executing it.